==> kaffeine_0.6.orig.tar.gz: kaffeine-0.6.orig/kaffeine/player-parts/http.h <==
/***************************************************************************
                          http.h - taken from the xine project
                          modified for use with c++
                             -------------------
    begin                : Fre Jan 23 2004
    revision             : $Revision: 1.4 $
    last modified        : $Date: 2005/02/02 10:08:25 $ by $Author: juergenk $
    copyright            : (C) 2004-2005 by Jürgen Kofler
    email                : kaffeine@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


/*
 * Copyright (C) 2002 the xine project
 * 
 * This file is part of xine, a free video player.
 * 
 * xine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * xine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 * Id: http.h,v 1.3 2002/12/22 14:23:01 holstsn Exp 
 */

#ifndef HAVE_HTTP_H
#define HAVE_HTTP_H


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

char *http_download (const char *url, int *file_size);

int http_peek (const char *url, int size, char *contents, char *mime_type);

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif

==> kaffeine_0.7.orig.tar.gz: kaffeine-0.7/kaffeine/player-parts/http.h <==
/***************************************************************************
                          http.h - taken from the xine project (http://www.xinehq.de)
                          modified for use with c++
                             -------------------
    begin                : Fre Jan 23 2004
    revision             : $Revision: 1.5 $
    last modified        : $Date: 2005/07/10 13:12:14 $ by $Author: juergenk $
    copyright            : (C) 2004-2005 by Jürgen Kofler
    email                : kaffeine@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef HAVE_HTTP_H
#define HAVE_HTTP_H


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

char *http_download (const char *url, int *file_size);

int http_peek (const char *url, int size, char *contents, char *mime_type);

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif
